@@ -86,6 +86,7 @@ describe 'neutron' do
     it_configures 'with host defined'
     it_configures 'with dns_domain defined'
     it_configures 'with transport_url defined'
+    it_configures 'with rootwrap daemon'
 
     context 'with amqp rpc_backend value' do
       it_configures 'amqp support'
@@ -142,7 +143,6 @@ describe 'neutron' do
       is_expected.to contain_neutron_config('DEFAULT/dhcp_agents_per_network').with_value('<SERVICE DEFAULT>')
       is_expected.to contain_neutron_config('DEFAULT/global_physnet_mtu').with_value('<SERVICE DEFAULT>')
       is_expected.to contain_neutron_config('DEFAULT/dhcp_agent_notification').with_value('<SERVICE DEFAULT>')
-      is_expected.to contain_neutron_config('DEFAULT/advertise_mtu').with_value('<SERVICE DEFAULT>')
       is_expected.to contain_neutron_config('DEFAULT/allow_bulk').with_value('<SERVICE DEFAULT>')
       is_expected.to contain_neutron_config('DEFAULT/allow_pagination').with_value('<SERVICE DEFAULT>')
       is_expected.to contain_neutron_config('DEFAULT/allow_sorting').with_value('<SERVICE DEFAULT>')
@@ -154,6 +154,7 @@ describe 'neutron' do
       is_expected.to contain_neutron_config('DEFAULT/transport_url').with_value('<SERVICE DEFAULT>')
       is_expected.to contain_neutron_config('DEFAULT/rpc_response_timeout').with_value( '<SERVICE DEFAULT>' )
       is_expected.to contain_neutron_config('agent/root_helper').with_value('sudo neutron-rootwrap /etc/neutron/rootwrap.conf')
+      is_expected.to contain_neutron_config('agent/root_helper_daemon').with_value('<SERVICE DEFAULT>')
       is_expected.to contain_neutron_config('agent/report_interval').with_value('<SERVICE DEFAULT>')
     end
   end
@@ -440,30 +441,6 @@ describe 'neutron' do
     end
   end
 
-  shared_examples_for 'with deprecated network_device_mtu defined' do
-    before do
-      params.merge!(
-        :network_device_mtu => 9000
-      )
-    end
-
-    it do
-      is_expected.to contain_neutron_config('DEFAULT/global_physnet_mtu').with_value(params[:network_device_mtu])
-    end
-  end
-
-  shared_examples_for 'with advertise_mtu defined' do
-    before do
-      params.merge!(
-        :advertise_mtu => true
-      )
-    end
-
-    it do
-      is_expected.to contain_neutron_config('DEFAULT/advertise_mtu').with_value(params[:advertise_mtu])
-    end
-  end
-
   shared_examples_for 'with host defined' do
     before do
       params.merge!(
@@ -500,6 +477,18 @@ describe 'neutron' do
     end
   end
 
+  shared_examples_for 'with rootwrap daemon' do
+    before do
+      params.merge!(
+        :root_helper_daemon => 'sudo neutron-rootwrap-daemon /etc/neutron/rootwrap.conf'
+      )
+    end
+
+    it do
+      is_expected.to contain_neutron_config('agent/root_helper_daemon').with_value(params[:root_helper_daemon])
+    end
+  end
+
   shared_examples_for 'amqp support' do
     context 'with default parameters' do
       before { params.merge!( :rpc_backend => 'amqp' ) }
